<?php

require dirname(__FILE__) . '/cookie-compliance-config.php';
require dirname(__FILE__) . '/cookie-compliance-language.php';

class Cookie_Compliance {

    const VERSION = '1.0';

    const TABLE_NAME = 'cookie_compliance_log';

    const OPTION_PREFIX = 'cookie_compliance_';

    private $options = array();

    private static $language = 'en';

    private static $languages = array('en' => 'English');
    
    public static function initialize() {

        if (function_exists('qtrans_getLanguage') && 
            function_exists('qtrans_getSortedLanguages') && 
            function_exists('qtrans_getLanguageName')) {
            
            self::$language = qtrans_getLanguage();

            foreach (qtrans_getSortedLanguages() as $language) {
                self::$languages[$language] = qtrans_getLanguageName($language);
            }
        }

	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

	if (is_plugin_active('polylang/polylang.php') &&
		function_exists('pll_current_language') &&
		function_exists('pll_the_languages')) {

		if (!is_admin()) {
			self::$language = pll_current_language('slug');
		} else {
			require_once(PLL_INC.'/core.php');
			$PolyLang = new Polylang_Core();
			require_once(PLL_INC.'/api.php');

			if (!$PolyLang->get_languages_list()) {
				// Polylang is enabled but does not return anuy languages...
			} else {
				$tmplang = get_object_vars($PolyLang->get_current_language());
				self::$language = $tmplang['slug'];

				if (isset($_GET['lang']) && isset($_GET['page']) && $_GET['page'] == 'cookie-compliance-settings') {
					self::$language = $_GET['lang'];
				}
				foreach ($PolyLang->get_languages_list() as $language) {
					$language = get_object_vars($language);
					self::$languages[$language['slug']] = $language['name'];
				}
			}
		}
	}





        $cookie_compliance_config = get_option(
            Cookie_Compliance::OPTION_PREFIX . "options", 
            new Cookie_Compliance_Config()
        );
        
        $cookie_compliance_language = get_option(
            Cookie_Compliance::OPTION_PREFIX . "language_" . self::$language,
            new Cookie_Compliance_Language(self::$language)
        );

        return new Cookie_Compliance(
            $cookie_compliance_config, 
            $cookie_compliance_language, 
            $cookie_compliance_languages
        );
     }

     public static function activate() {
         global $wpdb;

         require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

         $sql = sprintf("CREATE TABLE %s (
         id int(11) NOT NULL AUTO_INCREMENT,
         time TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
         ip_address VARCHAR(15) DEFAULT '' NOT NULL,
         user_agent TEXT NOT NULL,
         answer ENUM('accept', 'deny') DEFAULT 'deny' NOT NULL,
         PRIMARY KEY id (id));",  $wpdb->prefix . Cookie_Compliance::TABLE_NAME);

         dbDelta($sql);
         
         $sql = sprintf("CREATE TABLE %s (
         id int(11) NOT NULL AUTO_INCREMENT,
         time TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
         ip_address VARCHAR(15) DEFAULT '' NOT NULL,
         visitor TEXT NOT NULL,
         PRIMARY KEY id (id));",  $wpdb->prefix . 'cookie_compliance_visitor');

         dbDelta($sql);
         
         add_option("cookie_compliance_db_version", Cookie_Compliance::VERSION);
     }

     public function Cookie_Compliance(Cookie_Compliance_Config $config, Cookie_Compliance_Language $language, $languages = array()) {
        $this->config = $config;

        $this->languages = $this->languages + $languages;
        $this->language = $language;
        
        $this->add_settings();
        $this->add_actions();
    }
    
    private function setLanguage($short, Cookie_Compliance_Language $language) {
        update_option(Cookie_Compliance::OPTION_PREFIX . "language_$short", $language);
        $this->language = $language;
    }
    
    private function setConfig(Cookie_Compliance_Config $config) {
        update_option(Cookie_Compliance::OPTION_PREFIX . "options", $config);
        $this->config = $config;
    }
    
    private function getConfig() {
        return $this->language->getConfig() + $this->config->getOptions();
    }
    
    private function add_settings() {
        add_action( 'admin_menu' , array(&$this, 'admin_menu') );
    }
    
    public function admin_menu() {
        add_menu_page( 'Cookies', 'Cookies', 'manage_options', 'cookie-compliance', array(&$this, 'menu_page'), '', 81 );
	 add_submenu_page( 'cookie-compliance', 'Cookie Compliance', 'Cookie Compliance', 'manage_options', 'cookie-compliance', array(&$this, 'menu_page'));
        add_submenu_page( 'cookie-compliance', 'Pop-up Settings', 'Pop-up Settings', 'manage_options', 'cookie-compliance-settings', array(&$this, 'cookie_compliance_settings'));
    }
    
    public function menu_page() {
        
        if (0 === strcmp('POST', $_SERVER['REQUEST_METHOD']))  {
            $this->setConfig(new Cookie_Compliance_Config($_POST["cookie_compliance_options"]));
	     if ( function_exists( 'wp_cache_clean_cache' ) ) {
			global $file_prefix;
			wp_cache_clean_cache($file_prefix,true);
	     }
        }
        ?>
        
        <div class="wrap">
            <div style="padding-top:20px;">
                <h2>
                    <img width="34" height="32" style="vertical-align: middle; position: relative; top: -3px;" src="<?php echo plugins_url() ?>/cookie-compliance/cookie.jpg"> 
                    Cookie Compliance options - Script settings
                </h2>
            </div>

		This plugin is developed by <a href="https://zafrira.net" target="_blank">zafrira.net</a>, please visit the <a href="https://zafrira.net/en/tools/wordpress-plugins/cookie-compliance/" target="_blank">plugin page</a> to check for the latest details on this plugin or to contact us.<br />
		When you have suggestions, encounter problems or want a custom addition to this plugin, please visit our website for the contact details.

            <form method="post" action="<?php echo admin_url() ?>admin.php?page=cookie-compliance">

		<h3>Display Options</h3>
		Below the display options of the plugin. Here you can choose to disable the big popup and to enable a constant bar on the bottom. You can also choose to display the bottom bar only when the cookies are disabled.<br /><br />
		<input type="checkbox" id="cookie_compliance_default_deny" name="cookie_compliance_options[default][deny]" <?php if ($this->config->getDefaultDeny()) : ?>checked="checked"<?php endif; ?>> 
		Disable pop-up (makes the plugin to choose the deny option by default for all visitors)<br /><br />
		<input type="checkbox" id="cookie_compliance_default_bottomdenied" name="cookie_compliance_options[default][bottomdenied]" <?php if ($this->config->getDefaultBottomdenied()) : ?>checked="checked"<?php endif; ?>> 
		Display bar at the bottom when cookie usage is denied.<br /><br />
		<input type="checkbox" id="cookie_compliance_default_bottompopup" name="cookie_compliance_options[default][bottompopup]" <?php if ($this->config->getDefaultBottompopup()) : ?>checked="checked"<?php endif; ?>> 
		Display bar at the bottom in stead of the big popup.<br /><br />
		<input type="checkbox" id="cookie_compliance_default_nocookie" name="cookie_compliance_options[default][nocookie]" <?php if ($this->config->getDefaultNocookie()) : ?>checked="checked"<?php endif; ?>> 
		Do not store a cookie when the user chooses deny<br /><br />
                
                <h3>Cookie enabled</h3>
                Below fill in the javascript code to execute when your visitor allowed you to store cookies. You can add code to the header and footer.
                <table class="form-table">
                    <tbody>
                        <tr valign="top">
                            <th scope="row">Header</th>
                            <td>
                                <textarea id="cookie_compliance_enabled_head"   rows="5" name="cookie_compliance_options[enabled][head]"
                                    ><?php echo $this->config->getEnabledHead() ?></textarea>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th scope="row">Footer</th>
                            <td>
                                <textarea id="cookie_compliance_enabled_footer" rows="5" name="cookie_compliance_options[enabled][footer]"
                                    ><?php echo $this->config->getEnabledFooter() ?></textarea>
                            </td>
                        </tr>
                    </tbody>
                </table>
                
                <h3>Cookie disabled</h3>
                Below fill in the javascript code to execute when your visitor denied you to store cookies, or when cookie storing is not available. You can add code to the header and footer.
                <table class="form-table">
                    <tbody>
                        <tr valign="top">
                            <th scope="row">Header</th>
                            <td>
                                <textarea id="cookie_compliance_disabled_head"   rows="5" name="cookie_compliance_options[disabled][head]"
                                    ><?php echo $this->config->getDisabledHead() ?></textarea>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th scope="row">Footer</th>
                            <td>
                                <textarea id="cookie_compliance_disabled_footer" rows="5" name="cookie_compliance_options[disabled][footer]"
                                    ><?php echo $this->config->getDisabledFooter() ?></textarea>
                            </td>
                        </tr>
                    </tbody>
                </table>   
                

		<?php 
		if(function_exists('fsockopen')) {
		?>

                <h3><input type="checkbox" id="cookie_compliance_ga_enabled" name="cookie_compliance_options[ga][enabled]" 
                    <?php if ($this->config->getGAEnabled()) : ?>checked="checked"<?php endif; ?>> Google Analytics</h3>
		  Below fill in the settings when you would like to use Google Analytics. The plugin will make sure no tracking cookies are used when your visitor chooses to deny cookies or when cookies are not available.
                <table id="cookie_compliance_ga" class="form-table" <?php if (!$this->config->getGAEnabled()) : ?>style="display: none;"<?php endif; ?>>
                    <tbody>
                        <tr valign="top">
                            <th scope="row">UA Code</th>
                            <td>
                                <input type="text" id="cookie_compliance_ga_uacode" rows="5" name="cookie_compliance_options[ga][uacode]" 
                                    value="<?php echo $this->config->getGAUACode() ?>">
                            </td>
                        </tr>
                        <tr valign="top">
                            <th scope="row">Type</th>
                            <td>
                                <select id="cookie_compliance_ga_type"  name="cookie_compliance_options[ga][type]">
                                    <?php foreach (array('single' => 'Single', 
                                            'multi_sub' => 'Domain with multiple subdomains', 
                                            'multi_tld' => 'Domain with multiple TLD\'s') as $key => $desc) : ?>
                                        <option value="<?php echo $key ?>" <?php if ($this->config->getGAType() == $key) : ?>selected="selected"<?php endif; ?>><?php echo $desc ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th scope="row">Domain</th>
                            <td>
                                <input type="text" id="cookie_compliance_ga_domain" rows="5" name="cookie_compliance_options[ga][domain]" 
                                    value="<?php echo $this->config->getGADomain() ?>">
                            </td>
                        </tr>
                    </tbody>
                </table>   
		<?php
		} else {
		?>
		<h3>Google Analytics</h3>
		The Google Analytics function can only be enabled when the php function <i>fsockopen</i> is enabled and available.<br />
		If you would like to use this option, please request your hosting provider to enable the php function <i>fsockopen</i>.
          	<?php
		}
		?>
                
                <p class="submit">
                    <input type="submit" class="button-primary" value="Save Changes">
                </p>
            </form>
        </div>
        <style type="text/css">
            .form-table textarea,
            .form-table input,
            .form-table select {
                width: 500px;
            }
        </style>
        <script type="text/javascript">
            jQuery('#cookie_compliance_ga_enabled').change(function() {
                jQuery('#cookie_compliance_ga').css('display', jQuery(this).is(':checked') ? 'block' : 'none').css('width', '75%');
            })
        </script>
        
        <?php $this->footer() ?>
        <?php
    }
    
    public function cookie_compliance_settings() {
        
        if (function_exists('qtrans_getLanguage')) {
            $activeLanguageShort = qtrans_getLanguage();
            $activeLanguageName = self::$languages[$activeLanguageShort];
        }
        else {
            $language = array_slice(self::$languages, 0, 1, true);
            $language = array_keys($language);
            
            $activeLanguageShort = $this->language->getLanguageShortCode();
            $activeLanguageName = self::$languages[$activeLanguageShort];
        }

	if (isset($_GET['lang'])) {
		$activeLanguageShort = $_GET['lang'];
		$activeLanguageName = self::$languages[$activeLanguageShort];
		self::$language = $activeLanguageShort;
	}

        if (0 === strcmp('POST', $_SERVER['REQUEST_METHOD']))  {
            
            $_POST['cookie_compliance_language']['notify'] =
                stripslashes($_POST['cookie_compliance_language']['notify']);

            $_POST['cookie_compliance_language']['buttons']['submit'] =
                stripslashes($_POST['cookie_compliance_language']['buttons']['submit']);

            $_POST['cookie_compliance_language']['buttons']['cancel'] =
                stripslashes($_POST['cookie_compliance_language']['buttons']['cancel']);
            
            $language = new Cookie_Compliance_Language(
                $activeLanguageShort, 
                $_POST["cookie_compliance_language"]
            );
            
            $this->setLanguage($activeLanguageShort, $language);

		if ( function_exists( 'wp_cache_clean_cache' ) ) {
			global $file_prefix;
			wp_cache_clean_cache($file_prefix,true);
		}
        }
        
        ?>
        <div class="wrap" style="width: 75%;">
            <div style="padding-top:20px; height: 47px;">
                <h2 style="float: left;">
                    <img width="34" height="32" style="vertical-align: middle; position: relative; top: -3px;" src="<?php echo plugins_url() ?>/cookie-compliance/cookie.jpg"> 
                    Cookie Compliance options - Pop-up settings
                </h2>
                <?php if (count(self::$languages) > 0) : ?>
                    <select name="cookie_compliance_language" id="cookie_compliance_language" style="float: right; margin-top: 10px;">
                        <?php foreach (self::$languages as $languageShort => $languageName) : ?>
                            <option value="<?php echo $languageShort ?>" <?php if ($languageShort == $activeLanguageShort) : ?>selected="selected"<?php endif; ?>>
                                <?php echo $languageName ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                <?php endif; ?>
            </div>

		This plugin is developed by <a href="https://zafrira.net" target="_blank">zafrira.net</a>, please visit the <a href="https://zafrira.net/en/tools/wordpress-plugins/cookie-compliance/" target="_blank">plugin page</a> to check for the latest details on this plugin or to contact us.<br />
		When you have suggestions, encounter problems or want a custom addition to this plugin, please visit our website for the contact details.


            <form method="post" action="<?php echo admin_url() ?>admin.php?page=cookie-compliance-settings&lang=<?php echo $activeLanguageShort ?>">

                <input type="hidden" name="cookie_compliance_language" value="<?php echo $activeLanguageShort ?>">

                <h3>Pop up details (<?php echo $activeLanguageName ?>)</h3>
                
                <table class="form-table">
                    <tbody>
                        <tr valign="top">
                            <th scope="row">Message</th>
                            <td>
                                <?php wp_editor($this->language->getNotifyText(), 'cookie_compliance_language[notify]', array('wpautop' => false)) ?>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th scope="row">Approval</th>
                            <td>
                                <input type="text" id="cookie_compliance_buttons_submit" name="cookie_compliance_language[buttons][submit]" 
                                    value="<?php echo $this->language->getButtonSubmitText() ?>">
                            </td>
                        </tr>
                        <tr valign="top">
                            <th scope="row">Rejection</th>
                            <td>
                                <input type="text" id="cookie_compliance_buttons_cancel" name="cookie_compliance_language[buttons][cancel]" 
                                    value="<?php echo $this->language->getButtonCancelText() ?>">
                            </td>
                        </tr>
                    </tbody>
                </table>
                <p class="submit">
                    <input type="submit" class="button-primary" value="Save Changes">
                </p>
            </form>
        </div>
        <script type="text/javascript">
            jQuery('#cookie_compliance_language').change(function() {
                window.location.href = '<?php echo admin_url('admin.php?page=cookie-compliance-settings') ?>&lang=' + jQuery(this).val();
            })
        </script>

        <?php $this->footer() ?>

        <?php
    }
    
    private function footer() { 
        ?>
            <!--<img style="position: fixed; bottom: 41px; z-index: -1000; right: 20px;" src="<?php echo plugins_url() ?>/cookie-compliance/cookie-monster.jpg" />-->
        <?php
    }
    
    private function add_actions() {
        if ( ! is_admin() ) {
            add_action( 'wp_enqueue_scripts',               array(&$this, 'wp_enqueue_scripts') );
            add_action( 'wp_enqueue_scripts',               array(&$this, 'wp_enqueue_styles')  );
        }
        
        add_action( 'wp_head',                              array(&$this, 'wp_head')        );            
        add_action( 'wp_footer',                            array(&$this, 'wp_footer')      );
    }

    public function wp_enqueue_scripts() {
        wp_enqueue_script( 'cookie-compliance', plugins_url('cookie-compliance') . '/cookie-compliance.js', array('jquery') );
        wp_localize_script( 'cookie-compliance', 'cookie_compliance_options', 
            $this->getConfig() + array(
                'ajaxurl' => plugins_url('cookie-compliance') . '/ajax.php', 
                'nonce' => wp_create_nonce('cookie-compliance-nonce'),
                'ga_nonce' => wp_create_nonce('cookie-compliance-ga-nonce')
            ));
    }
    
    public function wp_enqueue_styles() {
        if (! $this->config->getDefaultDeny() ) {
		wp_enqueue_style( 'cookie-compliance' , plugins_url('cookie-compliance')  . '/cookie-compliance.css' );
	} else {
		if ($this->config->getDefaultBottomdenied()) {
			wp_enqueue_style( 'cookie-compliance' , plugins_url('cookie-compliance')  . '/cookie-compliance.css' );
		}
	}
    }
    
    public function wp_head() {
        ?>
        <script type="text/javascript">
        function cookie_compliance_head() {
            if (compliance.enabled() && compliance.check() && compliance.isAccepted()) {
                <?php echo $this->config->getEnabledHead() ?>
            } else {
                <?php echo $this->config->getDisabledHead() ?>
            }
        }
        </script>
        <?php
    }

     public function wp_footer() {
         ?><script type="text/javascript">
<?php if ($this->config->getGAEnabled()) : ?>var _gaq = _gaq || [];
<?php switch ($this->config->getGAType()) {
	case 'multi_tld' : ?>_gaq.push(['_setAllowLinker', true]);
<?php // falthru
	case 'multi_sub' : ?>_gaq.push(['_setDomainName', '<?php echo $this->config->getGADomain() ?>']);
<?php // falthru
	case 'single' :    ?>_gaq.push(['_setAccount', '<?php echo $this->config->getGAUACode() ?>']);
_gaq.push(['_trackPageview']);
<?php } ?>
<?php endif; ?>

function cookie_compliance_footer() {
	if (compliance.enabled() && compliance.check() && compliance.isAccepted()) {
	<?php echo $this->config->getEnabledFooter() ?>
<?php if ($this->config->getGAEnabled()) : ?>
	(function() {
	 var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
	 ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
	 var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
	})();
<?php endif; ?>
	} else {
	<?php echo $this->config->getDisabledFooter() ?>
<?php if ($this->config->getGAEnabled()) : ?>	jQuery.post(compliance.options.ajaxurl, { action: 'cookie_compliance_analytics', path: window.location.pathname, title: document.title, nonce: compliance.options.ga_nonce, ga_referrer: document.referrer });<?php endif; ?>
	}
}
</script><?php
     }

}